"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PhoneNumberWithCidTypedDict(TypedDict):
    r"""An object defining the message recipient telephone number with the message's custom identifier assigned by the User"""

    nr: str
    r"""A telephone number in international format (with a plus sign and the country code at the beginning, e.g. +48 for Poland)"""
    cid: NotRequired[str]
    r"""Custom message ID assigned by the User"""


class PhoneNumberWithCid(BaseModel):
    r"""An object defining the message recipient telephone number with the message's custom identifier assigned by the User"""

    nr: str
    r"""A telephone number in international format (with a plus sign and the country code at the beginning, e.g. +48 for Poland)"""

    cid: Optional[str] = None
    r"""Custom message ID assigned by the User"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from gsmservice_gateway.models import ClientError
from gsmservice_gateway.types import BaseModel
import httpx
from typing import Optional


class ErrorResponseErrorData(BaseModel):
    type: Optional[str] = None
    r"""A URI reference that identifies the problem type"""

    status: Optional[int] = None
    r"""The HTTP status code generated by the origin server for this occurrence of the problem"""

    title: Optional[str] = None
    r"""A short, human-readable summary of the problem type"""

    detail: Optional[str] = None
    r"""A human-readable explanation specific to this occurrence of the problem"""

    code: Optional[str] = None
    r"""An API specific error code aiding the provider team understand the error based on their own potential taxonomy or registry"""

    instance: Optional[str] = None
    r"""A URI reference that identifies the specific occurrence of the problem"""


@dataclass(frozen=True)
class ErrorResponseError(ClientError):
    r"""An object that complies with RFC 9457 containing information about a request error"""

    data: ErrorResponseErrorData = field(hash=False)

    def __init__(
        self,
        data: ErrorResponseErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.detail) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .message import Message, MessageTypedDict
from .smsmessage import SmsMessage, SmsMessageTypedDict
from gsmservice_gateway.types import BaseModel
from typing import Dict, List, Union
from typing_extensions import TypeAliasType, TypedDict


SendSmsRequestBodyTypedDict = TypeAliasType(
    "SendSmsRequestBodyTypedDict", Union[SmsMessageTypedDict, List[SmsMessageTypedDict]]
)
r"""To send a single SMS or messages with the same content to multiple recipients, please pass a single `SmsMessage` object with the properties of this message. To send multiple messages with different content at the same time, please pass `List[SmsMessage]` with the properties of each message."""


SendSmsRequestBody = TypeAliasType(
    "SendSmsRequestBody", Union[SmsMessage, List[SmsMessage]]
)
r"""To send a single SMS or messages with the same content to multiple recipients, please pass a single `SmsMessage` object with the properties of this message. To send multiple messages with different content at the same time, please pass `List[SmsMessage]` with the properties of each message."""


class SendSmsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[MessageTypedDict]


class SendSmsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[Message]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import UnrecognizedInt
from typing import Literal, Union


MessageType = Union[
    Literal[
        1,
        3,
        4,
        10,
    ],
    UnrecognizedInt,
]
r"""Message type (1 -> SMS PRO, 3 -> SMS ECO, 4 -> SMS 2WAY, 10 -> MMS)"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ErrorResponseTypedDict(TypedDict):
    r"""An object that complies with RFC 9457 containing information about a request error"""

    type: NotRequired[str]
    r"""A URI reference that identifies the problem type"""
    status: NotRequired[int]
    r"""The HTTP status code generated by the origin server for this occurrence of the problem"""
    title: NotRequired[str]
    r"""A short, human-readable summary of the problem type"""
    detail: NotRequired[str]
    r"""A human-readable explanation specific to this occurrence of the problem"""
    code: NotRequired[str]
    r"""An API specific error code aiding the provider team understand the error based on their own potential taxonomy or registry"""
    instance: NotRequired[str]
    r"""A URI reference that identifies the specific occurrence of the problem"""


class ErrorResponse(BaseModel):
    r"""An object that complies with RFC 9457 containing information about a request error"""

    type: Optional[str] = None
    r"""A URI reference that identifies the problem type"""

    status: Optional[int] = None
    r"""The HTTP status code generated by the origin server for this occurrence of the problem"""

    title: Optional[str] = None
    r"""A short, human-readable summary of the problem type"""

    detail: Optional[str] = None
    r"""A human-readable explanation specific to this occurrence of the problem"""

    code: Optional[str] = None
    r"""An API specific error code aiding the provider team understand the error based on their own potential taxonomy or registry"""

    instance: Optional[str] = None
    r"""A URI reference that identifies the specific occurrence of the problem"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mmsmessage import MmsMessage, MmsMessageTypedDict
from .price import Price, PriceTypedDict
from gsmservice_gateway.types import BaseModel
from typing import Dict, List, Union
from typing_extensions import TypeAliasType, TypedDict


GetMmsPriceRequestBodyTypedDict = TypeAliasType(
    "GetMmsPriceRequestBodyTypedDict",
    Union[MmsMessageTypedDict, List[MmsMessageTypedDict]],
)
r"""To check the price of a single message or messages with the same content to multiple recipients, pass a single `MmsMessage` object with the properties of this message. To check the price of multiple messages with different content at the same time, pass a `List[MmsMessage]` with the properties of each message."""


GetMmsPriceRequestBody = TypeAliasType(
    "GetMmsPriceRequestBody", Union[MmsMessage, List[MmsMessage]]
)
r"""To check the price of a single message or messages with the same content to multiple recipients, pass a single `MmsMessage` object with the properties of this message. To check the price of multiple messages with different content at the same time, pass a `List[MmsMessage]` with the properties of each message."""


class GetMmsPriceResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[PriceTypedDict]


class GetMmsPriceResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[Price]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .price import Price, PriceTypedDict
from .smsmessage import SmsMessage, SmsMessageTypedDict
from gsmservice_gateway.types import BaseModel
from typing import Dict, List, Union
from typing_extensions import TypeAliasType, TypedDict


GetSmsPriceRequestBodyTypedDict = TypeAliasType(
    "GetSmsPriceRequestBodyTypedDict",
    Union[SmsMessageTypedDict, List[SmsMessageTypedDict]],
)
r"""To check the price of a single message or messages with the same content to multiple recipients, pass a single `SmsMessage` object with the properties of this message. To check the price of multiple messages with different content at the same time, pass a `List[SmsMessage]` with the properties of each message."""


GetSmsPriceRequestBody = TypeAliasType(
    "GetSmsPriceRequestBody", Union[SmsMessage, List[SmsMessage]]
)
r"""To check the price of a single message or messages with the same content to multiple recipients, pass a single `SmsMessage` object with the properties of this message. To check the price of multiple messages with different content at the same time, pass a `List[SmsMessage]` with the properties of each message."""


class GetSmsPriceResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[PriceTypedDict]


class GetSmsPriceResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[Price]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .clienterror import ClientError
from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .accountresponse import AccountResponse, AccountResponseTypedDict, AccountType
    from .addsenderop import AddSenderResponse, AddSenderResponseTypedDict
    from .cancelledmessage import CancelledMessage, CancelledMessageTypedDict
    from .cancelmessagesop import (
        CancelMessagesRequest,
        CancelMessagesRequestTypedDict,
        CancelMessagesResponse,
        CancelMessagesResponseTypedDict,
    )
    from .deletesenderop import (
        DeleteSenderRequest,
        DeleteSenderRequestTypedDict,
        DeleteSenderResponse,
        DeleteSenderResponseTypedDict,
    )
    from .errorresponse import ErrorResponse, ErrorResponseTypedDict
    from .errorresponse_error import ErrorResponseError, ErrorResponseErrorData
    from .getincomingmessagesop import (
        GetIncomingMessagesRequest,
        GetIncomingMessagesRequestTypedDict,
        GetIncomingMessagesResponse,
        GetIncomingMessagesResponseTypedDict,
    )
    from .getmessagesop import (
        GetMessagesRequest,
        GetMessagesRequestTypedDict,
        GetMessagesResponse,
        GetMessagesResponseTypedDict,
    )
    from .getmmspriceop import (
        GetMmsPriceRequestBody,
        GetMmsPriceRequestBodyTypedDict,
        GetMmsPriceResponse,
        GetMmsPriceResponseTypedDict,
    )
    from .getsmspriceop import (
        GetSmsPriceRequestBody,
        GetSmsPriceRequestBodyTypedDict,
        GetSmsPriceResponse,
        GetSmsPriceResponseTypedDict,
    )
    from .getsubaccountdetailsop import (
        GetSubaccountDetailsRequest,
        GetSubaccountDetailsRequestTypedDict,
    )
    from .incomingmessage import IncomingMessage, IncomingMessageTypedDict
    from .listincomingmessagesop import (
        ListIncomingMessagesRequest,
        ListIncomingMessagesRequestTypedDict,
        ListIncomingMessagesResponse,
        ListIncomingMessagesResponseTypedDict,
    )
    from .listmessagesop import (
        ListMessagesRequest,
        ListMessagesRequestTypedDict,
        ListMessagesResponse,
        ListMessagesResponseTypedDict,
    )
    from .message import Message, MessageTypedDict
    from .messagetype import MessageType
    from .mmsmessage import (
        Attachments,
        AttachmentsTypedDict,
        MmsMessage,
        MmsMessageTypedDict,
        Recipients,
        RecipientsTypedDict,
    )
    from .no_response_error import NoResponseError
    from .phonenumberwithcid import PhoneNumberWithCid, PhoneNumberWithCidTypedDict
    from .pingresponse import PingResponse, PingResponseTypedDict
    from .price import Price, PriceTypedDict
    from .responsevalidationerror import ResponseValidationError
    from .sdkerror import SDKError
    from .security import Security, SecurityTypedDict
    from .sender import Sender, SenderTypedDict
    from .sender_input import SenderInput, SenderInputTypedDict
    from .sendmmsop import (
        SendMmsRequestBody,
        SendMmsRequestBodyTypedDict,
        SendMmsResponse,
        SendMmsResponseTypedDict,
    )
    from .sendsmsop import (
        SendSmsRequestBody,
        SendSmsRequestBodyTypedDict,
        SendSmsResponse,
        SendSmsResponseTypedDict,
    )
    from .setdefaultsenderop import (
        SetDefaultSenderRequest,
        SetDefaultSenderRequestTypedDict,
        SetDefaultSenderResponse,
        SetDefaultSenderResponseTypedDict,
    )
    from .smsmessage import (
        SmsMessage,
        SmsMessageRecipients,
        SmsMessageRecipientsTypedDict,
        SmsMessageTypedDict,
    )
    from .smstype import SmsType

__all__ = [
    "AccountResponse",
    "AccountResponseTypedDict",
    "AccountType",
    "AddSenderResponse",
    "AddSenderResponseTypedDict",
    "Attachments",
    "AttachmentsTypedDict",
    "CancelMessagesRequest",
    "CancelMessagesRequestTypedDict",
    "CancelMessagesResponse",
    "CancelMessagesResponseTypedDict",
    "CancelledMessage",
    "CancelledMessageTypedDict",
    "ClientError",
    "DeleteSenderRequest",
    "DeleteSenderRequestTypedDict",
    "DeleteSenderResponse",
    "DeleteSenderResponseTypedDict",
    "ErrorResponse",
    "ErrorResponseError",
    "ErrorResponseErrorData",
    "ErrorResponseTypedDict",
    "GetIncomingMessagesRequest",
    "GetIncomingMessagesRequestTypedDict",
    "GetIncomingMessagesResponse",
    "GetIncomingMessagesResponseTypedDict",
    "GetMessagesRequest",
    "GetMessagesRequestTypedDict",
    "GetMessagesResponse",
    "GetMessagesResponseTypedDict",
    "GetMmsPriceRequestBody",
    "GetMmsPriceRequestBodyTypedDict",
    "GetMmsPriceResponse",
    "GetMmsPriceResponseTypedDict",
    "GetSmsPriceRequestBody",
    "GetSmsPriceRequestBodyTypedDict",
    "GetSmsPriceResponse",
    "GetSmsPriceResponseTypedDict",
    "GetSubaccountDetailsRequest",
    "GetSubaccountDetailsRequestTypedDict",
    "IncomingMessage",
    "IncomingMessageTypedDict",
    "ListIncomingMessagesRequest",
    "ListIncomingMessagesRequestTypedDict",
    "ListIncomingMessagesResponse",
    "ListIncomingMessagesResponseTypedDict",
    "ListMessagesRequest",
    "ListMessagesRequestTypedDict",
    "ListMessagesResponse",
    "ListMessagesResponseTypedDict",
    "Message",
    "MessageType",
    "MessageTypedDict",
    "MmsMessage",
    "MmsMessageTypedDict",
    "NoResponseError",
    "PhoneNumberWithCid",
    "PhoneNumberWithCidTypedDict",
    "PingResponse",
    "PingResponseTypedDict",
    "Price",
    "PriceTypedDict",
    "Recipients",
    "RecipientsTypedDict",
    "ResponseValidationError",
    "SDKError",
    "Security",
    "SecurityTypedDict",
    "SendMmsRequestBody",
    "SendMmsRequestBodyTypedDict",
    "SendMmsResponse",
    "SendMmsResponseTypedDict",
    "SendSmsRequestBody",
    "SendSmsRequestBodyTypedDict",
    "SendSmsResponse",
    "SendSmsResponseTypedDict",
    "Sender",
    "SenderInput",
    "SenderInputTypedDict",
    "SenderTypedDict",
    "SetDefaultSenderRequest",
    "SetDefaultSenderRequestTypedDict",
    "SetDefaultSenderResponse",
    "SetDefaultSenderResponseTypedDict",
    "SmsMessage",
    "SmsMessageRecipients",
    "SmsMessageRecipientsTypedDict",
    "SmsMessageTypedDict",
    "SmsType",
]

_dynamic_imports: dict[str, str] = {
    "AccountResponse": ".accountresponse",
    "AccountResponseTypedDict": ".accountresponse",
    "AccountType": ".accountresponse",
    "AddSenderResponse": ".addsenderop",
    "AddSenderResponseTypedDict": ".addsenderop",
    "CancelledMessage": ".cancelledmessage",
    "CancelledMessageTypedDict": ".cancelledmessage",
    "CancelMessagesRequest": ".cancelmessagesop",
    "CancelMessagesRequestTypedDict": ".cancelmessagesop",
    "CancelMessagesResponse": ".cancelmessagesop",
    "CancelMessagesResponseTypedDict": ".cancelmessagesop",
    "DeleteSenderRequest": ".deletesenderop",
    "DeleteSenderRequestTypedDict": ".deletesenderop",
    "DeleteSenderResponse": ".deletesenderop",
    "DeleteSenderResponseTypedDict": ".deletesenderop",
    "ErrorResponse": ".errorresponse",
    "ErrorResponseTypedDict": ".errorresponse",
    "ErrorResponseError": ".errorresponse_error",
    "ErrorResponseErrorData": ".errorresponse_error",
    "GetIncomingMessagesRequest": ".getincomingmessagesop",
    "GetIncomingMessagesRequestTypedDict": ".getincomingmessagesop",
    "GetIncomingMessagesResponse": ".getincomingmessagesop",
    "GetIncomingMessagesResponseTypedDict": ".getincomingmessagesop",
    "GetMessagesRequest": ".getmessagesop",
    "GetMessagesRequestTypedDict": ".getmessagesop",
    "GetMessagesResponse": ".getmessagesop",
    "GetMessagesResponseTypedDict": ".getmessagesop",
    "GetMmsPriceRequestBody": ".getmmspriceop",
    "GetMmsPriceRequestBodyTypedDict": ".getmmspriceop",
    "GetMmsPriceResponse": ".getmmspriceop",
    "GetMmsPriceResponseTypedDict": ".getmmspriceop",
    "GetSmsPriceRequestBody": ".getsmspriceop",
    "GetSmsPriceRequestBodyTypedDict": ".getsmspriceop",
    "GetSmsPriceResponse": ".getsmspriceop",
    "GetSmsPriceResponseTypedDict": ".getsmspriceop",
    "GetSubaccountDetailsRequest": ".getsubaccountdetailsop",
    "GetSubaccountDetailsRequestTypedDict": ".getsubaccountdetailsop",
    "IncomingMessage": ".incomingmessage",
    "IncomingMessageTypedDict": ".incomingmessage",
    "ListIncomingMessagesRequest": ".listincomingmessagesop",
    "ListIncomingMessagesRequestTypedDict": ".listincomingmessagesop",
    "ListIncomingMessagesResponse": ".listincomingmessagesop",
    "ListIncomingMessagesResponseTypedDict": ".listincomingmessagesop",
    "ListMessagesRequest": ".listmessagesop",
    "ListMessagesRequestTypedDict": ".listmessagesop",
    "ListMessagesResponse": ".listmessagesop",
    "ListMessagesResponseTypedDict": ".listmessagesop",
    "Message": ".message",
    "MessageTypedDict": ".message",
    "MessageType": ".messagetype",
    "Attachments": ".mmsmessage",
    "AttachmentsTypedDict": ".mmsmessage",
    "MmsMessage": ".mmsmessage",
    "MmsMessageTypedDict": ".mmsmessage",
    "Recipients": ".mmsmessage",
    "RecipientsTypedDict": ".mmsmessage",
    "NoResponseError": ".no_response_error",
    "PhoneNumberWithCid": ".phonenumberwithcid",
    "PhoneNumberWithCidTypedDict": ".phonenumberwithcid",
    "PingResponse": ".pingresponse",
    "PingResponseTypedDict": ".pingresponse",
    "Price": ".price",
    "PriceTypedDict": ".price",
    "ResponseValidationError": ".responsevalidationerror",
    "SDKError": ".sdkerror",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "Sender": ".sender",
    "SenderTypedDict": ".sender",
    "SenderInput": ".sender_input",
    "SenderInputTypedDict": ".sender_input",
    "SendMmsRequestBody": ".sendmmsop",
    "SendMmsRequestBodyTypedDict": ".sendmmsop",
    "SendMmsResponse": ".sendmmsop",
    "SendMmsResponseTypedDict": ".sendmmsop",
    "SendSmsRequestBody": ".sendsmsop",
    "SendSmsRequestBodyTypedDict": ".sendsmsop",
    "SendSmsResponse": ".sendsmsop",
    "SendSmsResponseTypedDict": ".sendsmsop",
    "SetDefaultSenderRequest": ".setdefaultsenderop",
    "SetDefaultSenderRequestTypedDict": ".setdefaultsenderop",
    "SetDefaultSenderResponse": ".setdefaultsenderop",
    "SetDefaultSenderResponseTypedDict": ".setdefaultsenderop",
    "SmsMessage": ".smsmessage",
    "SmsMessageRecipients": ".smsmessage",
    "SmsMessageRecipientsTypedDict": ".smsmessage",
    "SmsMessageTypedDict": ".smsmessage",
    "SmsType": ".smstype",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from gsmservice_gateway import models, utils
from gsmservice_gateway._hooks import HookContext
from gsmservice_gateway.types import OptionalNullable, UNSET
from gsmservice_gateway.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional


class Common(BaseSDK):
    def ping(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PingResponse:
        r"""Checks API availability and version

        Check the API connection and the current API availability status. Also you will get the current API version number.

        As a successful result a `PingResponse` object will be returned.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="GET",
            path="/ping",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="ping",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "4XX", "503", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PingResponse, http_res)
        if utils.match_response(http_res, ["400", "4XX"], "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, ["503", "5XX"], "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def ping_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PingResponse:
        r"""Checks API availability and version

        Check the API connection and the current API availability status. Also you will get the current API version number.

        As a successful result a `PingResponse` object will be returned.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="GET",
            path="/ping",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="ping",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "4XX", "503", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PingResponse, http_res)
        if utils.match_response(http_res, ["400", "4XX"], "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, ["503", "5XX"], "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from gsmservice_gateway import models, utils
from gsmservice_gateway._hooks import HookContext
from gsmservice_gateway.types import BaseModel, OptionalNullable, UNSET
from gsmservice_gateway.utils import get_security_from_env
from gsmservice_gateway.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional, Union, cast


class Mms(BaseSDK):
    def get_price(
        self,
        *,
        request: Union[
            models.GetMmsPriceRequestBody, models.GetMmsPriceRequestBodyTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetMmsPriceResponse:
        r"""Check the price of MMS Messages

        Check the price of single or multiple MMS messages at the same time before sending them. You can pass as a `request` named parameter a single `MmsMessage` (for single message) or `List[MmsMessage]` (for multiple messages). Each `MmsMessage` object has several properties, describing message parameters such as recipient phone number, content of the message, attachments, etc.
        The method will accept maximum **50** messages in one call.

        As a successful result a `GetMmsPriceResponse` object will be returned with `result` property of type `List[Price]` containing a `Price` objects, one object per each single message. You should check the `error` property of each `Price` object to make sure which messages were priced successfully and which finished with an error. Successfully priced messages will have `null` value of `error` property.

        `GetSmsPriceResponse` object will include also `headers` property with `X-Success-Count` (a count of messages which were processed successfully) and `X-Error-Count` (count of messages which were rejected) elements.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.GetMmsPriceRequestBody)
        request = cast(models.GetMmsPriceRequestBody, request)

        req = self._build_request(
            method="POST",
            path="/messages/mms/price",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.GetMmsPriceRequestBody
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getMmsPrice",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.GetMmsPriceResponse(
                result=unmarshal_json_response(List[models.Price], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def get_price_async(
        self,
        *,
        request: Union[
            models.GetMmsPriceRequestBody, models.GetMmsPriceRequestBodyTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetMmsPriceResponse:
        r"""Check the price of MMS Messages

        Check the price of single or multiple MMS messages at the same time before sending them. You can pass as a `request` named parameter a single `MmsMessage` (for single message) or `List[MmsMessage]` (for multiple messages). Each `MmsMessage` object has several properties, describing message parameters such as recipient phone number, content of the message, attachments, etc.
        The method will accept maximum **50** messages in one call.

        As a successful result a `GetMmsPriceResponse` object will be returned with `result` property of type `List[Price]` containing a `Price` objects, one object per each single message. You should check the `error` property of each `Price` object to make sure which messages were priced successfully and which finished with an error. Successfully priced messages will have `null` value of `error` property.

        `GetSmsPriceResponse` object will include also `headers` property with `X-Success-Count` (a count of messages which were processed successfully) and `X-Error-Count` (count of messages which were rejected) elements.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.GetMmsPriceRequestBody)
        request = cast(models.GetMmsPriceRequestBody, request)

        req = self._build_request_async(
            method="POST",
            path="/messages/mms/price",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.GetMmsPriceRequestBody
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getMmsPrice",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.GetMmsPriceResponse(
                result=unmarshal_json_response(List[models.Price], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    def send(
        self,
        *,
        request: Union[models.SendMmsRequestBody, models.SendMmsRequestBodyTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SendMmsResponse:
        r"""Send MMS Messages

        Send single or multiple MMS messages at the same time. You can pass as a `request` named parameter a single `MmsMessage` object (for single message) or `List[MmsMessage]` (for multiple messages). Each `MmsMessage` object has several properties, describing message parameters such recipient phone number, content of the message, attachments or scheduled sending date, etc. This method will accept maximum 50 messages in one call.

        As a successful result a `SendMmsResponse` object will be returned with `result` property of type `List[Message]` containing `Message` objects, one object per each single message. You should check the `status_code` property of each `Message` object to make sure which messages were accepted by gateway (queued) and which were rejected. In case of rejection, `status_description` property will include a reason.

        `SendMmsResponse` will also include `headers` property with `X-Success-Count` (a count of messages which were processed successfully), `X-Error-Count` (count of messages which were rejected) and `X-Sandbox` (if a request was made in Sandbox or Production system) elements.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.SendMmsRequestBody)
        request = cast(models.SendMmsRequestBody, request)

        req = self._build_request(
            method="POST",
            path="/messages/mms",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.SendMmsRequestBody
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="sendMms",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.SendMmsResponse(
                result=unmarshal_json_response(List[models.Message], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def send_async(
        self,
        *,
        request: Union[models.SendMmsRequestBody, models.SendMmsRequestBodyTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SendMmsResponse:
        r"""Send MMS Messages

        Send single or multiple MMS messages at the same time. You can pass as a `request` named parameter a single `MmsMessage` object (for single message) or `List[MmsMessage]` (for multiple messages). Each `MmsMessage` object has several properties, describing message parameters such recipient phone number, content of the message, attachments or scheduled sending date, etc. This method will accept maximum 50 messages in one call.

        As a successful result a `SendMmsResponse` object will be returned with `result` property of type `List[Message]` containing `Message` objects, one object per each single message. You should check the `status_code` property of each `Message` object to make sure which messages were accepted by gateway (queued) and which were rejected. In case of rejection, `status_description` property will include a reason.

        `SendMmsResponse` will also include `headers` property with `X-Success-Count` (a count of messages which were processed successfully), `X-Error-Count` (count of messages which were rejected) and `X-Sandbox` (if a request was made in Sandbox or Production system) elements.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.SendMmsRequestBody)
        request = cast(models.SendMmsRequestBody, request)

        req = self._build_request_async(
            method="POST",
            path="/messages/mms",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.SendMmsRequestBody
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="sendMms",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.SendMmsResponse(
                result=unmarshal_json_response(List[models.Message], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


AccountType = Literal[
    "PRE-PAID",
    "POST-PAID",
]
r"""Account type"""


class AccountResponseTypedDict(TypedDict):
    r"""An object containing information about the User's account and balance"""

    login: NotRequired[str]
    r"""User Login"""
    account_type: NotRequired[AccountType]
    r"""Account type"""
    limit: NotRequired[float]
    r"""Acount limit"""
    credit: NotRequired[float]
    r"""Current account balance"""
    subcredit: NotRequired[Nullable[float]]
    r"""Subaccount credit balance (null if unlimited)"""
    currency: NotRequired[str]
    r"""Account currency"""
    name: NotRequired[str]
    r"""User name and surname"""
    is_main: NotRequired[bool]
    r"""Is main account?"""


class AccountResponse(BaseModel):
    r"""An object containing information about the User's account and balance"""

    login: Optional[str] = None
    r"""User Login"""

    account_type: Optional[AccountType] = None
    r"""Account type"""

    limit: Optional[float] = None
    r"""Acount limit"""

    credit: Optional[float] = None
    r"""Current account balance"""

    subcredit: OptionalNullable[float] = UNSET
    r"""Subaccount credit balance (null if unlimited)"""

    currency: Optional[str] = None
    r"""Account currency"""

    name: Optional[str] = None
    r"""User name and surname"""

    is_main: Optional[bool] = None
    r"""Is main account?"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "login",
            "account_type",
            "limit",
            "credit",
            "subcredit",
            "currency",
            "name",
            "is_main",
        ]
        nullable_fields = ["subcredit"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from gsmservice_gateway import models, utils
from gsmservice_gateway._hooks import HookContext
from gsmservice_gateway.types import OptionalNullable, UNSET
from gsmservice_gateway.utils import get_security_from_env
from gsmservice_gateway.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional


class Incoming(BaseSDK):
    def list(
        self,
        *,
        page: Optional[int] = 1,
        limit: Optional[int] = 10,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListIncomingMessagesResponse:
        r"""List the received SMS messages

        Get the details of all received messages from your account incoming messages box. This method supports pagination so you have to pass `page` (number of page with received messages which you want to access) and a `limit` (max of received messages per page) named parameters. Messages are fetched from the latest one. This method will accept maximum **50** as `limit` parameter value.

        As a successful result a `ListIncomingMessagesResponse` object will be returned with `result` property of type `List[IncomingMessage]` containing `IncomingMessage` objects, each object per single received message. `ListIncomingMessagesResponse` object will contain also a `headers` property where you can find `X-Total-Results` (a total count of all received messages which are available in incoming box on your account), `X-Total-Pages` (a total number of all pages with results), `X-Current-Page` (A current page number) and `X-Limit` (messages count per single page) elements.

        :param page: Page number of results
        :param limit: Number of results on one page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListIncomingMessagesRequest(
            page=page,
            limit=limit,
        )

        req = self._build_request(
            method="GET",
            path="/incoming",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listIncomingMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ListIncomingMessagesResponse(
                result=unmarshal_json_response(List[models.IncomingMessage], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        page: Optional[int] = 1,
        limit: Optional[int] = 10,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListIncomingMessagesResponse:
        r"""List the received SMS messages

        Get the details of all received messages from your account incoming messages box. This method supports pagination so you have to pass `page` (number of page with received messages which you want to access) and a `limit` (max of received messages per page) named parameters. Messages are fetched from the latest one. This method will accept maximum **50** as `limit` parameter value.

        As a successful result a `ListIncomingMessagesResponse` object will be returned with `result` property of type `List[IncomingMessage]` containing `IncomingMessage` objects, each object per single received message. `ListIncomingMessagesResponse` object will contain also a `headers` property where you can find `X-Total-Results` (a total count of all received messages which are available in incoming box on your account), `X-Total-Pages` (a total number of all pages with results), `X-Current-Page` (A current page number) and `X-Limit` (messages count per single page) elements.

        :param page: Page number of results
        :param limit: Number of results on one page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListIncomingMessagesRequest(
            page=page,
            limit=limit,
        )

        req = self._build_request_async(
            method="GET",
            path="/incoming",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listIncomingMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ListIncomingMessagesResponse(
                result=unmarshal_json_response(List[models.IncomingMessage], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    def get_by_ids(
        self,
        *,
        ids: List[int],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetIncomingMessagesResponse:
        r"""Get the incoming messages by IDs

        Get the details of one or more received messages using their `ids`. This method accepts a `List[int]` as a `ids` named parameter containing unique incoming message *IDs*, which were given while receiving a messages. The method will accept maximum 50 identifiers in one call.

        As a successful result a `GetIncomingMessagesResponse` object will be returned with an `result` property of type `List[IncomingMessage]` containing `IncomingMessage` objects, each object per single received message. `GetIncomingMessagesResponse` object will contain also a `headers` property where you can find `X-Success-Count` (a count of incoming messages which were found and returned correctly) and `X-Error-Count` (count of incoming messages which were not found) elements.

        :param ids: List[str] with Message IDs assigned by the system. The system will accept a maximum of 50 identifiers in one call.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetIncomingMessagesRequest(
            ids=ids,
        )

        req = self._build_request(
            method="GET",
            path="/incoming/{ids}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getIncomingMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.GetIncomingMessagesResponse(
                result=unmarshal_json_response(List[models.IncomingMessage], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def get_by_ids_async(
        self,
        *,
        ids: List[int],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetIncomingMessagesResponse:
        r"""Get the incoming messages by IDs

        Get the details of one or more received messages using their `ids`. This method accepts a `List[int]` as a `ids` named parameter containing unique incoming message *IDs*, which were given while receiving a messages. The method will accept maximum 50 identifiers in one call.

        As a successful result a `GetIncomingMessagesResponse` object will be returned with an `result` property of type `List[IncomingMessage]` containing `IncomingMessage` objects, each object per single received message. `GetIncomingMessagesResponse` object will contain also a `headers` property where you can find `X-Success-Count` (a count of incoming messages which were found and returned correctly) and `X-Error-Count` (count of incoming messages which were not found) elements.

        :param ids: List[str] with Message IDs assigned by the system. The system will accept a maximum of 50 identifiers in one call.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetIncomingMessagesRequest(
            ids=ids,
        )

        req = self._build_request_async(
            method="GET",
            path="/incoming/{ids}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getIncomingMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.GetIncomingMessagesResponse(
                result=unmarshal_json_response(List[models.IncomingMessage], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import BaseModel
from typing_extensions import TypedDict


class SenderTypedDict(TypedDict):
    r"""An object with the properties of the message sender"""

    sender: str
    r"""Message sender name"""
    status: str
    r"""Sender name status"""
    is_default: bool
    r"""Is the sender default?"""


class Sender(BaseModel):
    r"""An object with the properties of the message sender"""

    sender: str
    r"""Message sender name"""

    status: str
    r"""Sender name status"""

    is_default: bool
    r"""Is the sender default?"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sender import Sender, SenderTypedDict
from gsmservice_gateway.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class AddSenderResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: SenderTypedDict


class AddSenderResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: Sender



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import BaseModel
from gsmservice_gateway.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetSubaccountDetailsRequestTypedDict(TypedDict):
    user_login: str
    r"""Login of the subaccount (user) to get the data for"""


class GetSubaccountDetailsRequest(BaseModel):
    user_login: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=True))
    ]
    r"""Login of the subaccount (user) to get the data for"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import BaseModel
from typing_extensions import TypedDict


class SenderInputTypedDict(TypedDict):
    r"""An object with the properties of the message sender"""

    sender: str
    r"""Message sender name"""
    description: str
    r"""Description of the purpose of the sender name (required when adding new sender name)"""


class SenderInput(BaseModel):
    r"""An object with the properties of the message sender"""

    sender: str
    r"""Message sender name"""

    description: str
    r"""Description of the purpose of the sender name (required when adding new sender name)"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .phonenumberwithcid import PhoneNumberWithCid, PhoneNumberWithCidTypedDict
from datetime import datetime
from gsmservice_gateway.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


RecipientsTypedDict = TypeAliasType(
    "RecipientsTypedDict",
    Union[
        PhoneNumberWithCidTypedDict, str, List[str], List[PhoneNumberWithCidTypedDict]
    ],
)
r"""The recipient number or multiple recipients numbers of single message. To set one recipient, simply pass a `str` with his phone number. To set multiple recipients, please pass `List[str]`. Optionally you can also set custom id (user identifier) for each message - pass `PhoneNumberWithCid` object (in case of single recipient) or List[PhoneNumberWithCid] (in case of multiple recipients)."""


Recipients = TypeAliasType(
    "Recipients", Union[PhoneNumberWithCid, str, List[str], List[PhoneNumberWithCid]]
)
r"""The recipient number or multiple recipients numbers of single message. To set one recipient, simply pass a `str` with his phone number. To set multiple recipients, please pass `List[str]`. Optionally you can also set custom id (user identifier) for each message - pass `PhoneNumberWithCid` object (in case of single recipient) or List[PhoneNumberWithCid] (in case of multiple recipients)."""


AttachmentsTypedDict = TypeAliasType("AttachmentsTypedDict", Union[str, List[str]])
r"""Attachments for the message. You can pass here images, audio and video files bodies. To set one attachment please pass a `str` with attachment body encoded with `base64`. To set multiple attachments - pass `List[str]` with attachments bodies encoded with `base64`. Max 3 attachments per message."""


Attachments = TypeAliasType("Attachments", Union[str, List[str]])
r"""Attachments for the message. You can pass here images, audio and video files bodies. To set one attachment please pass a `str` with attachment body encoded with `base64`. To set multiple attachments - pass `List[str]` with attachments bodies encoded with `base64`. Max 3 attachments per message."""


class MmsMessageTypedDict(TypedDict):
    r"""An object with a new MMS message properties"""

    recipients: RecipientsTypedDict
    r"""The recipient number or multiple recipients numbers of single message. To set one recipient, simply pass a `str` with his phone number. To set multiple recipients, please pass `List[str]`. Optionally you can also set custom id (user identifier) for each message - pass `PhoneNumberWithCid` object (in case of single recipient) or List[PhoneNumberWithCid] (in case of multiple recipients)."""
    subject: NotRequired[Nullable[str]]
    r"""MMS message subject"""
    message: NotRequired[Nullable[str]]
    r"""MMS message content"""
    attachments: NotRequired[AttachmentsTypedDict]
    r"""Attachments for the message. You can pass here images, audio and video files bodies. To set one attachment please pass a `str` with attachment body encoded with `base64`. To set multiple attachments - pass `List[str]` with attachments bodies encoded with `base64`. Max 3 attachments per message."""
    date_: NotRequired[Nullable[datetime]]
    r"""Scheduled future date and time of sending the message (in ISO 8601 format). If missing or null - message will be sent immediately"""


class MmsMessage(BaseModel):
    r"""An object with a new MMS message properties"""

    recipients: Recipients
    r"""The recipient number or multiple recipients numbers of single message. To set one recipient, simply pass a `str` with his phone number. To set multiple recipients, please pass `List[str]`. Optionally you can also set custom id (user identifier) for each message - pass `PhoneNumberWithCid` object (in case of single recipient) or List[PhoneNumberWithCid] (in case of multiple recipients)."""

    subject: OptionalNullable[str] = UNSET
    r"""MMS message subject"""

    message: OptionalNullable[str] = UNSET
    r"""MMS message content"""

    attachments: Optional[Attachments] = None
    r"""Attachments for the message. You can pass here images, audio and video files bodies. To set one attachment please pass a `str` with attachment body encoded with `base64`. To set multiple attachments - pass `List[str]` with attachments bodies encoded with `base64`. Max 3 attachments per message."""

    date_: Annotated[OptionalNullable[datetime], pydantic.Field(alias="date")] = None
    r"""Scheduled future date and time of sending the message (in ISO 8601 format). If missing or null - message will be sent immediately"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["subject", "message", "attachments", "date"]
        nullable_fields = ["subject", "message", "date"]
        null_default_fields = ["date"]

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from gsmservice_gateway import models, utils
from gsmservice_gateway._hooks import HookContext
from gsmservice_gateway.mms import Mms
from gsmservice_gateway.sms import Sms
from gsmservice_gateway.types import OptionalNullable, UNSET
from gsmservice_gateway.utils import get_security_from_env
from gsmservice_gateway.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional


class Outgoing(BaseSDK):
    mms: Mms
    sms: Sms

    def __init__(
        self, sdk_config: SDKConfiguration, parent_ref: Optional[object] = None
    ) -> None:
        BaseSDK.__init__(self, sdk_config, parent_ref=parent_ref)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.mms = Mms(self.sdk_configuration, parent_ref=self.parent_ref)
        self.sms = Sms(self.sdk_configuration, parent_ref=self.parent_ref)

    def get_by_ids(
        self,
        *,
        ids: List[int],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetMessagesResponse:
        r"""Get the messages details and status by IDs

        Check the current status and details of one or more messages using their `ids`. You have to pass a `List[int]` as a `ids` named parameter containing unique message *IDs* which details you want to fetch. This method will accept maximum 50 identifiers in one call.

        As a successful result a `GetMessagesResponse` object will be returned containing `result` property of type `List[Message]` with `Message` objects, each object per single found message. `GetMessagesResponse` object will also contain `headers` property where you can find `X-Success-Count` (a count of messages which were found and returned correctly) and `X-Error-Count` (count of messages which were not found) elements.

        :param ids: List[str] with Message IDs assigned by the system. The system will accept a maximum of 50 identifiers in one call.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetMessagesRequest(
            ids=ids,
        )

        req = self._build_request(
            method="GET",
            path="/messages/{ids}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.GetMessagesResponse(
                result=unmarshal_json_response(List[models.Message], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def get_by_ids_async(
        self,
        *,
        ids: List[int],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetMessagesResponse:
        r"""Get the messages details and status by IDs

        Check the current status and details of one or more messages using their `ids`. You have to pass a `List[int]` as a `ids` named parameter containing unique message *IDs* which details you want to fetch. This method will accept maximum 50 identifiers in one call.

        As a successful result a `GetMessagesResponse` object will be returned containing `result` property of type `List[Message]` with `Message` objects, each object per single found message. `GetMessagesResponse` object will also contain `headers` property where you can find `X-Success-Count` (a count of messages which were found and returned correctly) and `X-Error-Count` (count of messages which were not found) elements.

        :param ids: List[str] with Message IDs assigned by the system. The system will accept a maximum of 50 identifiers in one call.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetMessagesRequest(
            ids=ids,
        )

        req = self._build_request_async(
            method="GET",
            path="/messages/{ids}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.GetMessagesResponse(
                result=unmarshal_json_response(List[models.Message], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    def cancel_scheduled(
        self,
        *,
        ids: List[int],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CancelMessagesResponse:
        r"""Cancel a scheduled messages

        Cancel messages using their `ids` which were scheduled to be sent at a specific time. You have to pass a `List[int]` as a `ids` named parameter containing the unique message IDs, which were returned after sending a message. This method will accept maximum 50 identifiers in one call. You can cancel only messages with *SCHEDULED* status.

        As a successful result a `CancelMessagesResponse` object will be returned, with `result` property of type `List[CancelledMessage]` containing `CancelledMessage` objects. The `status` property of each `CancelledMessage` object will contain a status code of operation - `204` if a particular message was cancelled successfully and other code if an error occured.

        `CancelMessagesResponse` object will also contain `headers` property where you can find `X-Success-Count` (a count of messages which were cancelled successfully), `X-Error-Count` (count of messages which were not cancelled) and `X-Sandbox` (if a request was made in Sandbox or Production system) elements.

        :param ids: List[str] with Message IDs assigned by the system. The system will accept a maximum of 50 identifiers in one call.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CancelMessagesRequest(
            ids=ids,
        )

        req = self._build_request(
            method="DELETE",
            path="/messages/{ids}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="cancelMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.CancelMessagesResponse(
                result=unmarshal_json_response(List[models.CancelledMessage], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def cancel_scheduled_async(
        self,
        *,
        ids: List[int],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CancelMessagesResponse:
        r"""Cancel a scheduled messages

        Cancel messages using their `ids` which were scheduled to be sent at a specific time. You have to pass a `List[int]` as a `ids` named parameter containing the unique message IDs, which were returned after sending a message. This method will accept maximum 50 identifiers in one call. You can cancel only messages with *SCHEDULED* status.

        As a successful result a `CancelMessagesResponse` object will be returned, with `result` property of type `List[CancelledMessage]` containing `CancelledMessage` objects. The `status` property of each `CancelledMessage` object will contain a status code of operation - `204` if a particular message was cancelled successfully and other code if an error occured.

        `CancelMessagesResponse` object will also contain `headers` property where you can find `X-Success-Count` (a count of messages which were cancelled successfully), `X-Error-Count` (count of messages which were not cancelled) and `X-Sandbox` (if a request was made in Sandbox or Production system) elements.

        :param ids: List[str] with Message IDs assigned by the system. The system will accept a maximum of 50 identifiers in one call.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CancelMessagesRequest(
            ids=ids,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/messages/{ids}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="cancelMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.CancelMessagesResponse(
                result=unmarshal_json_response(List[models.CancelledMessage], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    def list(
        self,
        *,
        page: Optional[int] = 1,
        limit: Optional[int] = 10,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListMessagesResponse:
        r"""Lists the history of sent messages

        Get the details and current status of all of sent messages from your account message history. This method supports pagination so you have to pass a `page` (number of page with messages which you want to access) and a `limit` (max of messages per page) named parameters. Messages are fetched from the latest one. This method will accept maximum value of **50** as `limit` parameter value.

        As a successful result a `ListMessagesResponse` object will be returned containing `result` property of type `List[Message]` with a `Message` objects, each object per single message. `ListMessagesResponse` will also contain `headers` property where you can find `X-Total-Results` (a total count of all messages which are available in history on your account), `X-Total-Pages` (a total number of all pages with results), `X-Current-Page` (A current page number) and `X-Limit` (messages count per single page) elements.

        :param page: Page number of results
        :param limit: Number of results on one page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListMessagesRequest(
            page=page,
            limit=limit,
        )

        req = self._build_request(
            method="GET",
            path="/messages",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ListMessagesResponse(
                result=unmarshal_json_response(List[models.Message], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        page: Optional[int] = 1,
        limit: Optional[int] = 10,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListMessagesResponse:
        r"""Lists the history of sent messages

        Get the details and current status of all of sent messages from your account message history. This method supports pagination so you have to pass a `page` (number of page with messages which you want to access) and a `limit` (max of messages per page) named parameters. Messages are fetched from the latest one. This method will accept maximum value of **50** as `limit` parameter value.

        As a successful result a `ListMessagesResponse` object will be returned containing `result` property of type `List[Message]` with a `Message` objects, each object per single message. `ListMessagesResponse` will also contain `headers` property where you can find `X-Total-Results` (a total count of all messages which are available in history on your account), `X-Total-Pages` (a total number of all pages with results), `X-Current-Page` (A current page number) and `X-Limit` (messages count per single page) elements.

        :param page: Page number of results
        :param limit: Number of results on one page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListMessagesRequest(
            page=page,
            limit=limit,
        )

        req = self._build_request_async(
            method="GET",
            path="/messages",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listMessages",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ListMessagesResponse(
                result=unmarshal_json_response(List[models.Message], http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from gsmservice_gateway.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IncomingMessageTypedDict(TypedDict):
    r"""An object with the properties of the received message"""

    id: NotRequired[int]
    r"""Unique identifier of incoming message"""
    login: NotRequired[str]
    r"""Login of the account (sub-account) on which the message was received"""
    recipient: NotRequired[str]
    r"""Recipient number (or service name)"""
    sender: NotRequired[str]
    r"""Message sender number (or alphanumeric name)"""
    phonebook_sender_name: NotRequired[Nullable[str]]
    r"""Sender name (matched with phonebook)"""
    date_: NotRequired[datetime]
    r"""Date and time of message receipt in ISO 8601 format"""
    message: NotRequired[str]
    r"""Received message content"""
    dedicated_number: NotRequired[Nullable[str]]
    r"""Dedicated Mobile Originated service number (if the message was received on this number)"""
    dedicated_prefix: NotRequired[Nullable[str]]
    r"""Dedicated Mobile Originated service prefix (if the message was received on this number with such prefix)"""


class IncomingMessage(BaseModel):
    r"""An object with the properties of the received message"""

    id: Optional[int] = None
    r"""Unique identifier of incoming message"""

    login: Optional[str] = None
    r"""Login of the account (sub-account) on which the message was received"""

    recipient: Optional[str] = None
    r"""Recipient number (or service name)"""

    sender: Optional[str] = None
    r"""Message sender number (or alphanumeric name)"""

    phonebook_sender_name: OptionalNullable[str] = UNSET
    r"""Sender name (matched with phonebook)"""

    date_: Annotated[Optional[datetime], pydantic.Field(alias="date")] = None
    r"""Date and time of message receipt in ISO 8601 format"""

    message: Optional[str] = None
    r"""Received message content"""

    dedicated_number: OptionalNullable[str] = UNSET
    r"""Dedicated Mobile Originated service number (if the message was received on this number)"""

    dedicated_prefix: OptionalNullable[str] = UNSET
    r"""Dedicated Mobile Originated service prefix (if the message was received on this number with such prefix)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "id",
            "login",
            "recipient",
            "sender",
            "phonebook_sender_name",
            "date",
            "message",
            "dedicated_number",
            "dedicated_prefix",
        ]
        nullable_fields = [
            "phonebook_sender_name",
            "dedicated_number",
            "dedicated_prefix",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from gsmservice_gateway import models, utils
from gsmservice_gateway._hooks import HookContext
from gsmservice_gateway.types import OptionalNullable, UNSET
from gsmservice_gateway.utils import get_security_from_env
from gsmservice_gateway.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional


class Accounts(BaseSDK):
    def get(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AccountResponse:
        r"""Get account details

        Get current account balance and other details of your account. You can check also account limit and if account is main one. Main accounts have unlimited privileges and using [User Panel](https://panel.szybkisms.pl) you can create as many subaccounts as you need.

        As a successful result a details of current account you are logged in using an API Access Token will be returned.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="GET",
            path="/account",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getAccountDetails",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "403", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.AccountResponse, http_res)
        if utils.match_response(
            http_res, ["401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def get_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AccountResponse:
        r"""Get account details

        Get current account balance and other details of your account. You can check also account limit and if account is main one. Main accounts have unlimited privileges and using [User Panel](https://panel.szybkisms.pl) you can create as many subaccounts as you need.

        As a successful result a details of current account you are logged in using an API Access Token will be returned.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="GET",
            path="/account",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getAccountDetails",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "403", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.AccountResponse, http_res)
        if utils.match_response(
            http_res, ["401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    def get_subaccount(
        self,
        *,
        user_login: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AccountResponse:
        r"""Get subaccount details

        Check account balance and other details such subcredit balance of a subaccount. Subaccounts are additional users who can access your account services and the details. You can restrict access level and setup privileges to subaccounts using [User Panel](https://panel.szybkisms.pl).

        This method accepts an `user_login` named parameter of type `str` with user login. You should pass there the full subaccount login to access its data.

        As a successful result the details of subaccount with provided login will be returned.

        :param user_login: Login of the subaccount (user) to get the data for
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetSubaccountDetailsRequest(
            user_login=user_login,
        )

        req = self._build_request(
            method="GET",
            path="/account/{user_login}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getSubaccountDetails",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.AccountResponse, http_res)
        if utils.match_response(
            http_res, ["401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def get_subaccount_async(
        self,
        *,
        user_login: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AccountResponse:
        r"""Get subaccount details

        Check account balance and other details such subcredit balance of a subaccount. Subaccounts are additional users who can access your account services and the details. You can restrict access level and setup privileges to subaccounts using [User Panel](https://panel.szybkisms.pl).

        This method accepts an `user_login` named parameter of type `str` with user login. You should pass there the full subaccount login to access its data.

        As a successful result the details of subaccount with provided login will be returned.

        :param user_login: Login of the subaccount (user) to get the data for
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetSubaccountDetailsRequest(
            user_login=user_login,
        )

        req = self._build_request_async(
            method="GET",
            path="/account/{user_login}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getSubaccountDetails",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.AccountResponse, http_res)
        if utils.match_response(
            http_res, ["401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "gsmservice-gateway"
__version__: str = "3.1.1"
__openapi_doc_version__: str = "1.2.2"
__gen_version__: str = "2.716.5"
__user_agent__: str = "speakeasy-sdk/python 3.1.1 2.716.5 1.2.2 gsmservice-gateway"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from enum import Enum
from gsmservice_gateway import models, utils
from gsmservice_gateway._hooks import HookContext
from gsmservice_gateway.types import BaseModel, OptionalNullable, UNSET
from gsmservice_gateway.utils import get_security_from_env
from gsmservice_gateway.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional, Union, cast


class SetDefaultAcceptEnum(str, Enum):
    APPLICATION_JSON = "application/json"
    APPLICATION_PROBLEM_PLUS_JSON = "application/problem+json"


class Senders(BaseSDK):
    def list(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.Sender]:
        r"""List allowed senders names

        Get a list of allowed senders defined in your account.

        As a successful result a `List[Sender]` containing `Sender` objects will be returned, each object per single sender.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="GET",
            path="/senders",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listSenders",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(List[models.Sender], http_res)
        if utils.match_response(
            http_res, ["400", "401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.Sender]:
        r"""List allowed senders names

        Get a list of allowed senders defined in your account.

        As a successful result a `List[Sender]` containing `Sender` objects will be returned, each object per single sender.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="GET",
            path="/senders",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listSenders",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(List[models.Sender], http_res)
        if utils.match_response(
            http_res, ["400", "401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    def add(
        self,
        *,
        request: Union[models.SenderInput, models.SenderInputTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AddSenderResponse:
        r"""Add a new sender name

        Define a new allowed sender on your account. You should pass as `request` named parameter a `SenderInput` object with two properties: `sender` (defines sender name) and `description`. Please carefully fill this property with the extensive description of a sender name (what will be its use, what the name mean, etc).

        As a successful result a `AddSenderResponse` object will be returned with a `result` property containing a `Sender` object with details and status of added sender name.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.SenderInput)
        request = cast(models.SenderInput, request)

        req = self._build_request(
            method="POST",
            path="/senders",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.SenderInput
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="addSender",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return models.AddSenderResponse(
                result=unmarshal_json_response(models.Sender, http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def add_async(
        self,
        *,
        request: Union[models.SenderInput, models.SenderInputTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AddSenderResponse:
        r"""Add a new sender name

        Define a new allowed sender on your account. You should pass as `request` named parameter a `SenderInput` object with two properties: `sender` (defines sender name) and `description`. Please carefully fill this property with the extensive description of a sender name (what will be its use, what the name mean, etc).

        As a successful result a `AddSenderResponse` object will be returned with a `result` property containing a `Sender` object with details and status of added sender name.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.SenderInput)
        request = cast(models.SenderInput, request)

        req = self._build_request_async(
            method="POST",
            path="/senders",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.SenderInput
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="addSender",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return models.AddSenderResponse(
                result=unmarshal_json_response(models.Sender, http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    def delete(
        self,
        *,
        sender: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteSenderResponse:
        r"""Delete a sender name

        Removes defined sender name from your account. This method accepts a `sender` named parameter with a **sender name** you want to remove. Sender name will be deleted immediately.

        As a successful response a `DeleteSenderResponse` object will be returned with no Exception thrown.

        :param sender: Sender name to be removed
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteSenderRequest(
            sender=sender,
        )

        req = self._build_request(
            method="DELETE",
            path="/senders/{sender}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/problem+json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteSender",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return models.DeleteSenderResponse(
                headers=utils.get_response_headers(http_res.headers)
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def delete_async(
        self,
        *,
        sender: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteSenderResponse:
        r"""Delete a sender name

        Removes defined sender name from your account. This method accepts a `sender` named parameter with a **sender name** you want to remove. Sender name will be deleted immediately.

        As a successful response a `DeleteSenderResponse` object will be returned with no Exception thrown.

        :param sender: Sender name to be removed
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteSenderRequest(
            sender=sender,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/senders/{sender}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/problem+json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteSender",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return models.DeleteSenderResponse(
                headers=utils.get_response_headers(http_res.headers)
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    def set_default(
        self,
        *,
        sender: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        accept_header_override: Optional[SetDefaultAcceptEnum] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SetDefaultSenderResponse:
        r"""Set default sender name

        Set default sender name to one of the senders names already defined on your account. This method accepts a `sender` named parameter containing a **sender name** to be set as default on your account.

        As a successful response a `SetDefaultSenderResponse` object will be returned with no exception to be thrown.

        :param sender: Sender name to set as default
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.SetDefaultSenderRequest(
            sender=sender,
        )

        req = self._build_request(
            method="PATCH",
            path="/senders/{sender}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value=accept_header_override.value
            if accept_header_override is not None
            else "application/json;q=1, application/problem+json;q=0",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="setDefaultSender",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return models.SetDefaultSenderResponse(
                headers=utils.get_response_headers(http_res.headers)
            )
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(
            http_res, ["400", "401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)

    async def set_default_async(
        self,
        *,
        sender: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        accept_header_override: Optional[SetDefaultAcceptEnum] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SetDefaultSenderResponse:
        r"""Set default sender name

        Set default sender name to one of the senders names already defined on your account. This method accepts a `sender` named parameter containing a **sender name** to be set as default on your account.

        As a successful response a `SetDefaultSenderResponse` object will be returned with no exception to be thrown.

        :param sender: Sender name to set as default
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.SetDefaultSenderRequest(
            sender=sender,
        )

        req = self._build_request_async(
            method="PATCH",
            path="/senders/{sender}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value=accept_header_override.value
            if accept_header_override is not None
            else "application/json;q=1, application/problem+json;q=0",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="setDefaultSender",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return models.SetDefaultSenderResponse(
                headers=utils.get_response_headers(http_res.headers)
            )
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(
            http_res, ["400", "401", "403", "4XX"], "application/problem+json"
        ):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)
        if utils.match_response(http_res, "5XX", "application/problem+json"):
            response_data = unmarshal_json_response(
                models.ErrorResponseErrorData, http_res
            )
            raise models.ErrorResponseError(response_data, http_res)

        raise models.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import BaseModel
from gsmservice_gateway.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class SetDefaultSenderRequestTypedDict(TypedDict):
    sender: str
    r"""Sender name to set as default"""


class SetDefaultSenderRequest(BaseModel):
    sender: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Sender name to set as default"""


class SetDefaultSenderResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]


class SetDefaultSenderResponse(BaseModel):
    headers: Dict[str, List[str]]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .phonenumberwithcid import PhoneNumberWithCid, PhoneNumberWithCidTypedDict
from .smstype import SmsType
from datetime import datetime
from gsmservice_gateway.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET_SENTINEL,
)
from gsmservice_gateway.utils import validate_open_enum
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


SmsMessageRecipientsTypedDict = TypeAliasType(
    "SmsMessageRecipientsTypedDict",
    Union[
        PhoneNumberWithCidTypedDict, str, List[str], List[PhoneNumberWithCidTypedDict]
    ],
)
r"""The recipient number or multiple recipients numbers of single message. To set one recipient, simply pass a `str` with his phone number. To set multiple recipients, please pass `List[str]`. Optionally you can also set custom id (user identifier) for each message - pass `PhoneNumberWithCid` object (in case of single recipient) or List[PhoneNumberWithCid] (in case of multiple recipients)."""


SmsMessageRecipients = TypeAliasType(
    "SmsMessageRecipients",
    Union[PhoneNumberWithCid, str, List[str], List[PhoneNumberWithCid]],
)
r"""The recipient number or multiple recipients numbers of single message. To set one recipient, simply pass a `str` with his phone number. To set multiple recipients, please pass `List[str]`. Optionally you can also set custom id (user identifier) for each message - pass `PhoneNumberWithCid` object (in case of single recipient) or List[PhoneNumberWithCid] (in case of multiple recipients)."""


class SmsMessageTypedDict(TypedDict):
    r"""An object with a new SMS message properties"""

    recipients: SmsMessageRecipientsTypedDict
    r"""The recipient number or multiple recipients numbers of single message. To set one recipient, simply pass a `str` with his phone number. To set multiple recipients, please pass `List[str]`. Optionally you can also set custom id (user identifier) for each message - pass `PhoneNumberWithCid` object (in case of single recipient) or List[PhoneNumberWithCid] (in case of multiple recipients)."""
    message: str
    r"""SMS message content"""
    sender: NotRequired[str]
    r"""SMS sender name"""
    type: NotRequired[SmsType]
    r"""SMS type (1 -> SMS PRO, 3 -> SMS ECO, 4 -> SMS 2WAY)"""
    unicode: NotRequired[bool]
    r"""Should the message be sent with special characters, e.g. Polish diacritics (if any)? If *false*, those characters will be automatically replaced with their equivalents. If *true* your message will be sent as **unicode** but the message will be able to consist of fewer characters."""
    flash: NotRequired[bool]
    r"""Should the message to be sent with class 0 (FLASH)?"""
    date_: NotRequired[Nullable[datetime]]
    r"""Scheduled future date and time of sending the message (in ISO 8601 format). If missing or null - message will be sent immediately"""


class SmsMessage(BaseModel):
    r"""An object with a new SMS message properties"""

    recipients: SmsMessageRecipients
    r"""The recipient number or multiple recipients numbers of single message. To set one recipient, simply pass a `str` with his phone number. To set multiple recipients, please pass `List[str]`. Optionally you can also set custom id (user identifier) for each message - pass `PhoneNumberWithCid` object (in case of single recipient) or List[PhoneNumberWithCid] (in case of multiple recipients)."""

    message: str
    r"""SMS message content"""

    sender: Optional[str] = "Bramka SMS"
    r"""SMS sender name"""

    type: Annotated[Optional[SmsType], PlainValidator(validate_open_enum(True))] = 1
    r"""SMS type (1 -> SMS PRO, 3 -> SMS ECO, 4 -> SMS 2WAY)"""

    unicode: Optional[bool] = False
    r"""Should the message be sent with special characters, e.g. Polish diacritics (if any)? If *false*, those characters will be automatically replaced with their equivalents. If *true* your message will be sent as **unicode** but the message will be able to consist of fewer characters."""

    flash: Optional[bool] = False
    r"""Should the message to be sent with class 0 (FLASH)?"""

    date_: Annotated[OptionalNullable[datetime], pydantic.Field(alias="date")] = None
    r"""Scheduled future date and time of sending the message (in ISO 8601 format). If missing or null - message will be sent immediately"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["sender", "type", "unicode", "flash", "date"]
        nullable_fields = ["date"]
        null_default_fields = ["date"]

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from dataclasses import dataclass


@dataclass(frozen=True)
class NoResponseError(Exception):
    """Error raised when no HTTP response is received from the server."""

    message: str

    def __init__(self, message: str = "No response received"):
        object.__setattr__(self, "message", message)
        super().__init__(message)

    def __str__(self):
        return self.message



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .incomingmessage import IncomingMessage, IncomingMessageTypedDict
from gsmservice_gateway.types import BaseModel
from gsmservice_gateway.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetIncomingMessagesRequestTypedDict(TypedDict):
    ids: List[int]
    r"""List[str] with Message IDs assigned by the system. The system will accept a maximum of 50 identifiers in one call."""


class GetIncomingMessagesRequest(BaseModel):
    ids: Annotated[
        List[int], FieldMetadata(path=PathParamMetadata(style="simple", explode=True))
    ]
    r"""List[str] with Message IDs assigned by the system. The system will accept a maximum of 50 identifiers in one call."""


class GetIncomingMessagesResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[IncomingMessageTypedDict]


class GetIncomingMessagesResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[IncomingMessage]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .message import Message, MessageTypedDict
from .mmsmessage import MmsMessage, MmsMessageTypedDict
from gsmservice_gateway.types import BaseModel
from typing import Dict, List, Union
from typing_extensions import TypeAliasType, TypedDict


SendMmsRequestBodyTypedDict = TypeAliasType(
    "SendMmsRequestBodyTypedDict", Union[MmsMessageTypedDict, List[MmsMessageTypedDict]]
)
r"""To send a single MMS or messages with the same content to multiple recipients, please pass a single `MmsMessage` object with the properties of this message. To send multiple messages with different content at the same time, please pass `List[MmsMessage]` with the properties of each message."""


SendMmsRequestBody = TypeAliasType(
    "SendMmsRequestBody", Union[MmsMessage, List[MmsMessage]]
)
r"""To send a single MMS or messages with the same content to multiple recipients, please pass a single `MmsMessage` object with the properties of this message. To send multiple messages with different content at the same time, please pass `List[MmsMessage]` with the properties of each message."""


class SendMmsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[MessageTypedDict]


class SendMmsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[Message]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .incomingmessage import IncomingMessage, IncomingMessageTypedDict
from gsmservice_gateway.types import BaseModel
from gsmservice_gateway.utils import FieldMetadata, QueryParamMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListIncomingMessagesRequestTypedDict(TypedDict):
    page: NotRequired[int]
    r"""Page number of results"""
    limit: NotRequired[int]
    r"""Number of results on one page"""


class ListIncomingMessagesRequest(BaseModel):
    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1
    r"""Page number of results"""

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 10
    r"""Number of results on one page"""


class ListIncomingMessagesResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[IncomingMessageTypedDict]


class ListIncomingMessagesResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[IncomingMessage]
